.. index:: subpackages and modules

.. _skpar:

=====================================
Subpackage/module Reference
=====================================

SKPAR currently includes the following sub-packages:

.. list-table::

    * - :ref:`core <skpar.core>` 
      - the core modules realising the optimisation framework

    * - :ref:`dftbutils <skpar.dftbutils>` 
      - the modules related to a DFTB model

.. toctree::

    skpar.core
    skpar.dftbutils
